@@ -36,6 +36,8 @@
 (require 'mailcap)
 (mailcap-parse-mimetypes)
 
+(defvar bbdb-mode-map)
+
 (defgroup gnorb nil
   "Glue code between Gnus, Org, and BBDB."
   :tag "Gnorb"
@@ -183,9 +185,9 @@ window."
   (let* ((sum-buffer (gnus-summary-buffer-name group))
 	 (target-buffer
 	  (cond
-	   ((gnus-buffer-exists-p sum-buffer)
+	   ((gnus-buffer-live-p sum-buffer)
 	    sum-buffer)
-	   ((gnus-buffer-exists-p gnus-group-buffer)
+	   ((gnus-buffer-live-p gnus-group-buffer)
 	    gnus-group-buffer)
 	   (t nil)))
 	 (target-window (when target-buffer
@@ -200,7 +202,7 @@ window."
       (if target-buffer
 	  (switch-to-buffer target-buffer)))
     (message "Following link...")
-    (if (gnus-buffer-exists-p sum-buffer)
+    (if (gnus-buffer-live-p sum-buffer)
 	(gnus-summary-goto-article id nil t)
       (gnorb-open-gnus-link group id))))
 
@@ -560,7 +562,9 @@ group."
     (nnvirtual
      (setq group (car (nnvirtual-map-article art-no))))
     (nnir
-     (setq group (nnir-article-group art-no))))
+     (setq group (nnir-article-group art-no)))
+    (nnselect
+     (setq group (nnselect-article-group art-no))))
   group)
 
 (defun gnorb-find-tracked-headings (headers &optional include-zombies)
